stat

package
v0.0.0-...-b9e61c6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2019 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BoxMueller

func BoxMueller(fr floatrange.Range) float64

BoxMueller is shorthand for BoxMuellerSin

func BoxMuellerCos

func BoxMuellerCos(fr floatrange.Range) float64

BoxMuellerCos returns Rcos(Theta)

func BoxMuellerSin

func BoxMuellerSin(fr floatrange.Range) float64

BoxMuellerSin returns Rsin(Theta)

func ConditionalEntropy

func ConditionalEntropy(samples []*env.F, a, b int) float64

ConditionalEntropy returns the conditional entropy of (a|b) in the assumption that the provided samples are bitstrings

func Entropy

func Entropy(f float64) float64

Entropy returns the entropy of a float64

func Factorial

func Factorial(n int) int

func MarginalEntropy

func MarginalEntropy(samples []*env.F, indices []int) float64

MarginalEntropy returns the marginal entropy of a subset of the given samples, where the subset is defined by a slice of indices in the sample environments.

func MinConditionalEntropy

func MinConditionalEntropy(samples []*env.F, prev int, available *[]int) int

MinConditionalEntropy finds the index of the given samples with the lowest entropy given the provided previous index, only checking indices in the available list. Afterward, the index chosen is removed from the available list.

func MinEntropy

func MinEntropy(samples []*env.F) (int, float64)

MinEntropy finds the index of the given samples with the lowest entropy. Also returns the univariate probability of the returned index.

Types

This section is empty.

Jump to