Documentation
¶
Index ¶
- func BoxMueller(fr floatrange.Range) float64
- func BoxMuellerCos(fr floatrange.Range) float64
- func BoxMuellerSin(fr floatrange.Range) float64
- func ConditionalEntropy(samples []*env.F, a, b int) float64
- func Entropy(f float64) float64
- func Factorial(n int) int
- func MarginalEntropy(samples []*env.F, indices []int) float64
- func MinConditionalEntropy(samples []*env.F, prev int, available *[]int) int
- func MinEntropy(samples []*env.F) (int, float64)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BoxMueller ¶
func BoxMueller(fr floatrange.Range) float64
BoxMueller is shorthand for BoxMuellerSin
func BoxMuellerCos ¶
func BoxMuellerCos(fr floatrange.Range) float64
BoxMuellerCos returns Rcos(Theta)
func BoxMuellerSin ¶
func BoxMuellerSin(fr floatrange.Range) float64
BoxMuellerSin returns Rsin(Theta)
func ConditionalEntropy ¶
ConditionalEntropy returns the conditional entropy of (a|b) in the assumption that the provided samples are bitstrings
func MarginalEntropy ¶
MarginalEntropy returns the marginal entropy of a subset of the given samples, where the subset is defined by a slice of indices in the sample environments.
func MinConditionalEntropy ¶
MinConditionalEntropy finds the index of the given samples with the lowest entropy given the provided previous index, only checking indices in the available list. Afterward, the index chosen is removed from the available list.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.